from omni.isaac.kit import SimulationApp

kit = SimulationApp({"headless": False})

from omni.isaac.urdf import _urdf
from omni.kit.commands import execute
from omni.isaac.core import World
from omni.isaac.core.utils.prims import move_prim
from omni.isaac.core.prims import RigidPrim

import numpy as np

physics_dt = 1/240
gravity_magnitude = 9.81

world = World(physics_dt=physics_dt, rendering_dt=physics_dt, stage_units_in_meters=1.0)
world.get_physics_context().set_gravity(-gravity_magnitude)
world.scene.add_default_ground_plane()

_, import_config = execute("URDFCreateImportConfig")
# Set defaults
import_config.merge_fixed_joints = False
import_config.convex_decomp = False
import_config.fix_base = False
import_config.import_inertia_tensor = True

root_path = "."
file_name = "block01.urdf"
urdf_interface = _urdf.acquire_urdf_interface()
imported_robot = urdf_interface.parse_urdf(root_path, file_name, import_config)
prim_path = urdf_interface.import_robot(root_path, file_name, imported_robot, import_config)
move_prim(prim_path, "/World/box")

prim = RigidPrim(prim_path="/World/box", position=np.array([0, 0, 1]), mass=1)
world.scene.add(prim)

world.reset()
while True:
    world.step()
